import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import aws_cdk._jsii
import cdk_spot_one._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-ec2spot", "2.0.133", __name__[0:-6], "cdk-ec2spot@2.0.133.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
